@@ -1620,6 +1620,9 @@ globus_rls_client_s2attr(globus_rls_attr_type_t type, char *sval,
  * rc and error specific message.  Exported in client API cause server
  * and this API both need it.
  */
+
+/* added the message Globus LRC server is busy... */
+
 char *
 globus_rls_errmsg(int rc, char *specificmsg, char *buf, int buflen)
 
@@ -1657,6 +1660,7 @@ globus_rls_errmsg(int rc, char *specificmsg, char *buf, int buflen)
     "Too many connections",
     "Attribute with specified value doesn't exist",
     "Attribute still referenced by objects in database",
+    "Server initialization in progress"
   };
 #define GLOBUS_RLS_NUMERRORS	(sizeof(baseerrmsg) /  sizeof(char *))
 
