@@ -215,6 +215,11 @@
  */
 #define GLOBUS_RLS_ATTR_INUSE		30
 
+/* Globus LRC server is in the process of starting up. You can issue queries
+but cannot update the database. */
+
+#define GLOBUS_RLS_INITIALIZING          31
+
 /**
  * @defgroup globus_rls_client_miscellaneous Miscellaneous
  * Miscellaneous functions and types.
@@ -1948,6 +1953,11 @@ typedef struct {
  * @ingroup globus_rls_client_miscellaneous
  */
 #define RLS_SNDBLOOMFILTER	0x20
+/**
+ * RLC is fully initialized.
+ * @ingroup globus_rls_client_miscellaneous
+ */
+#define RLS_INITIALIZED		0x40
 
 /**
  * Miscellaneous administrative operations.  Most operations require the
